#library(VennDiagram)
library(readr)
library(dplyr)
library(ggplot2)
library(forcats)

# load data, only 101 rows.

usecases <- read_delim("01_data/Use_cases.tsv",
"\t", escape_double = FALSE, trim_ws = TRUE,
skip = 3)[1:101,]

expanded =left_join(usecases,usecases, by = c("Closely_related_to"= "ID"))

write.csv(expanded , file = "doubles.csv")

## changing cluster, duplicating entry with multiple cluster
usecases2=usecases
usecases3=usecases [0,]
for (i in c(1:nrow(usecases))){
  if (usecases$Cluster[i] == "Documentation/ Metadata for Discovery"){
    add= usecases[i,]
    add$Cluster = "Documentation"
    usecases2$Cluster[i] <- "Metadata for Discovery"
  usecases2 = rbind (usecases2, add)
  usecases3 = rbind (usecases3,usecases2[i,], add)
  }
  if (usecases$Cluster[i] == "Documentation/ Metadata for Quality assessment"){
    add= usecases[i,]
    add$Cluster = "Documentation"
    usecases2$Cluster[i] <- "Metadata for Quality assessment"
    usecases2 = rbind (usecases2, add)
    usecases3 = rbind (usecases3,usecases2[i,], add)
  }
  if (usecases$Cluster[i] == "Linking/ Metadata for Discovery"){
    add= usecases[i,]
    add$Cluster = "Linking"
    usecases2$Cluster[i] <- "Metadata for Discovery"
    usecases2 = rbind (usecases2, add)
    usecases3 = rbind (usecases3,usecases2[i,], add)
  }
  if (usecases$Cluster[i] == "Not a use case"){
    add= usecases[i,]
    add$Cluster = "Linking"
    usecases2$Cluster[i] <- "Metadata for Discovery"
    usecases2 = rbind (usecases2, add)
    usecases3 = rbind (usecases3,usecases2[i,], add)
  }
}
View(usecases2)

## summary
usecases2$Cluster = factor(usecases2$Cluster)


### Prioritisation

prioritisation_answers <- read_delim("01_data/prioritisation_answers.tsv",
"\t", escape_double = FALSE, trim_ws = TRUE)


allans=c(prioritisation_answers$`Which cluster do you think is most relevant?`,
  prioritisation_answers$`Which cluster do you think is second most relevant?`,
  prioritisation_answers$`Which cluster do you think is least relevant?`,
  prioritisation_answers$`Which cluster do you think is also not very relevant?`)
answers =unique (allans)[1:12]

merging= data.frame("id"=1:12,"prioritisation"=answers,"cluster"=unique(usecases2$Cluster))
View(merging)
# write.csv(merging, file = "01_data/prioritisationclustermerge.csv") # saved on disk, changed manually

merging_mod <- read_csv("01_data/deriveddata-prioritisationclustermerge.csv")

# # putting all factors
# fact2 <- function(x){
#   factor(x, levels =as.list(merging_mod[,2])[[1]])
#   
# }
# prioritisation_answers$`Which cluster do you think is most relevant?`=
#   fact2(prioritisation_answers$`Which cluster do you think is most relevant?`)
# prioritisation_answers$`Which cluster do you think is second most relevant?`=fact2(prioritisation_answers$`Which cluster do you think is second most relevant?`)
# prioritisation_answers$`Which cluster do you think is least relevant?`=fact2(prioritisation_answers$`Which cluster do you think is least relevant?`)
# prioritisation_answers$`Which cluster do you think is also not very relevant?`=fact2(prioritisation_answers$`Which cluster do you think is also not very relevant?`)

# pool positive and negative
prioritisation_answersplus = data.frame("positive"=c(prioritisation_answers$`Which cluster do you think is most relevant?`,
                               prioritisation_answers$`Which cluster do you think is second most relevant?`),
                               "negative"=c(prioritisation_answers$`Which cluster do you think is least relevant?`,
                                            prioritisation_answers$`Which cluster do you think is also not very relevant?`))



P=prioritisation_answersplus %>% 
  group_by(positive) %>%
  summarise(positive_n = length(positive))
N=prioritisation_answersplus %>% 
  group_by(negative) %>%
  summarise(negative_n = length(negative))

# prepare for plotting
answerssummary=left_join(P,N, by =c("positive" = "negative"))
answerssummary=left_join(answerssummary,merging_mod, by =c("positive" = "prioritisation"))
names (answerssummary) = c("positive" ,  "high",
                           "low", "id" , "cluster")
require(reshape2)
df <- answerssummary %>% select(cluster, high, low)
df <- melt(df ,  id.vars = 'cluster', variable.name = 'type')
names (df) = c("cluster", "priority", "number of answers")
# plot
temp= usecases2 %>%
  mutate(Cluster = fct_reorder(Cluster, ID, .fun='length'))

ord_clust =levels(temp$Cluster)

## plots

F1=usecases2 %>%
  mutate(Cluster = fct_reorder(Cluster, ID, .fun='length')) %>%
  ggplot( aes(x=Cluster,  fill=Actor)) + 
  geom_bar(stat="count") + 
  coord_flip()+#theme(legend.position="none") +
  labs(
    title= paste0("Occurence of use cases per cluster and actor (total =", nrow(usecases)
                  , ")")
  ) +
  ylab("Amount of use cases")+
  xlab("Cluster")+theme_minimal(base_size = 17)


F2 = df %>%
  mutate(cluster = factor(cluster, levels = ord_clust), ranking =priority) %>%
  mutate_if(is.numeric, coalesce, 0) %>%
  ggplot(aes(cluster, `number of answers`)) +
  geom_point(aes(colour = ranking), size = 3) +
  coord_flip() +
  labs(title = paste0("Ranking score")) +
  expand_limits(y = 0) + theme_minimal(base_size = 17)

Ftot = gridExtra::grid.arrange(
  F1,
  F2 + theme (axis.title.y = element_blank(),
              axis.text.y = element_blank()),
  nrow = 1,
  widths = c(3, 1)
)

ggsave(
  "03_figures/summaryfig.png",
  plot = Ftot,
  #device = png,
  width = 40, height = 20, units = "cm"
)
#unique(usecases2$Actor)
